rankeval\.analysis package
==========================

.. automodule:: rankeval.analysis
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

rankeval\.analysis\.effectiveness module
----------------------------------------

.. automodule:: rankeval.analysis.effectiveness
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.analysis\.feature module
----------------------------------

.. automodule:: rankeval.analysis.feature
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.analysis\.statistical module
--------------------------------------

.. automodule:: rankeval.analysis.statistical
    :members:
    :undoc-members:
    :show-inheritance:

rankeval\.analysis\.topological module
--------------------------------------

.. automodule:: rankeval.analysis.topological
    :members:
    :undoc-members:
    :show-inheritance:


